summaryrefslogtreecommitdiffstats
path: root/bibletime/backend/cbookdisplay.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/backend/cbookdisplay.cpp')
-rw-r--r--bibletime/backend/cbookdisplay.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/bibletime/backend/cbookdisplay.cpp b/bibletime/backend/cbookdisplay.cpp
index 6215396..ffb97f4 100644
--- a/bibletime/backend/cbookdisplay.cpp
+++ b/bibletime/backend/cbookdisplay.cpp
@@ -57,13 +57,13 @@ namespace Rendering {
/**
* Check whether displaying displayLevel levels together is possible.
* For this count the childs and tqparents
* of the required position
*/
int possibleLevels = 1; //we start with the default value of displayLevel, which means no entries together
- while( key->parent() && (key->key() != "/") && !key->key().isEmpty() ) {//add tqparents
+ while( key->parent() && (key->key() != "/") && !key->key().isEmpty() ) {//add parents
++possibleLevels;
};
@@ -57,13 +57,13 @@ namespace Rendering {
/**
* Check whether displaying displayLevel levels together is possible.
- * For this count the childs and tqparents
+ * For this count the childs and parents
* of the required position
*/